@@ -190,7 +190,7 @@ price-type		5 g  currency-str		@ g  commodity-table		I g  c
 a	#	
 (	.	
 8	9	A	
-A	M	`	n	t	u	{										(	")	&1	2	;	?	@	R	f	z			 T	   C~EeHqrM~s      h     ]445 >  "  G  4 >  "  G  4 >  "  G  444L 5	5 >  "  G  4 >  "  G  4
+A	M	`	n	t	u	{										(	")	&1	2	;	?	@	R	f	z			 T	   C~EeHqrM~s      h     ]445 >  "  G  4 >  "  G  4 >  "  G  444L 5	5 >  "  G  4 >  "  G  4
 5 6            g  p
 	   g  filenamef  price-quotes.scm
 5		6		6		
